==> apache-dolphinscheduler-3.2.0-src.tar.gz: apache-dolphinscheduler-3.2.0-src/dolphinscheduler-task-plugin/dolphinscheduler-task-api/src/main/java/org/apache/dolphinscheduler/plugin/task/api/shell/sh/ShShellInterceptorBuilder.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.dolphinscheduler.plugin.task.api.shell.sh;

import org.apache.dolphinscheduler.plugin.task.api.shell.BaseLinuxShellInterceptorBuilder;

import java.io.IOException;
import java.util.List;

public class ShShellInterceptorBuilder
        extends
            BaseLinuxShellInterceptorBuilder<ShShellInterceptorBuilder, ShShellInterceptor> {

    @Override
    public ShShellInterceptorBuilder newBuilder() {
        return new ShShellInterceptorBuilder();
    }

    @Override
    public ShShellInterceptor build() throws IOException {
        generateShellScript();
        List<String> bootstrapCommand = generateBootstrapCommand();
        return new ShShellInterceptor(bootstrapCommand, shellDirectory);
    }

    @Override
    protected String shellHeader() {
        return "#!/bin/sh";
    }

    @Override
    protected String shellInterpreter() {
        return "sh";
    }

    @Override
    protected String shellExtension() {
        return ".sh";
    }
}

==> apache-dolphinscheduler-3.4.0-src.tar.gz: apache-dolphinscheduler-3.4.0-src/dolphinscheduler-task-plugin/dolphinscheduler-task-api/src/main/java/org/apache/dolphinscheduler/plugin/task/api/shell/sh/ShShellInterceptorBuilder.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.dolphinscheduler.plugin.task.api.shell.sh;

import org.apache.dolphinscheduler.common.exception.FileOperateException;
import org.apache.dolphinscheduler.plugin.task.api.shell.BaseLinuxShellInterceptorBuilder;

import java.io.IOException;
import java.util.List;

public class ShShellInterceptorBuilder
        extends
            BaseLinuxShellInterceptorBuilder<ShShellInterceptorBuilder, ShShellInterceptor> {

    @Override
    public ShShellInterceptorBuilder newBuilder() {
        return new ShShellInterceptorBuilder();
    }

    @Override
    public ShShellInterceptor build() throws IOException, FileOperateException {
        generateShellScript();
        List<String> bootstrapCommand = generateBootstrapCommand();
        return new ShShellInterceptor(bootstrapCommand, shellDirectory);
    }

    @Override
    protected String shellHeader() {
        return "#!/bin/sh";
    }

    @Override
    protected String shellInterpreter() {
        return "sh";
    }

    @Override
    protected String shellExtension() {
        return ".sh";
    }
}
